#------------------------------------------------------------------------------
# Setup.py
#   Setup module for the module cx_Oracle. For Win32, use the option
# --compiler=mingw32 for compilation.
#------------------------------------------------------------------------------

import os, sys
from distutils.core import setup
from distutils.extension import Extension

# define some variables
v_OracleHome = os.environ["ORACLE_HOME"]
if sys.platform == "win32":
  v_Includes = [os.path.join(v_OracleHome, "oci", "include")]
  v_LibDirs = ["/Tools/Lib"]
  v_Libs = ["oci"]
else:
  v_Includes = ["rdbms/demo", "rdbms/public", "network/public"]
  v_Includes = [os.path.join(v_OracleHome, p) for p in v_Includes]
  v_LibDirs = [os.path.join(v_OracleHome, "lib")]
  v_Libs = ["clntsh"]

# setup the extension
v_Extension = Extension(
    name = "cx_Oracle",
    include_dirs = v_Includes,
    libraries = v_Libs,
    library_dirs = v_LibDirs,
    extra_link_args = ["-s"],
    sources = ["cx_Oracle.c"])

# perform the setup
setup(
    name = "cx_Oracle",
    version = "2.1.0",
    description = "Python interface to Oracle",
    author = "Anthony Tuininga, Computronix",
    author_email = "atuining@computronix.com",
    url = "http://www.computronix.com",
    ext_modules = [v_Extension])

